Struct OrganizationInviteCryptoBundle
pub struct OrganizationInviteCryptoBundle {
pub invite_key: InviteKeyData,
pub invite: Invite,
}Expand description
The cryptographic bundle returned when generating an organization member invite link.
invite_key: raw invite key encoded as base64Url. MUST NOT be sent to the server.invite: invite key sealed with the organization key, serialized as an EncString. Safe to send to the server.
Fields
invite_key: InviteKeyDataRaw invite key. CRITICAL: MUST NOT be sent to the server.
invite: InviteInvite key sealed with the organization key. Safe to send to the server.