Struct OrganizationUsersManagementClient
pub struct OrganizationUsersManagementClient {
pub(crate) api_configurations: Arc<ApiConfigurations>,
}Expand description
Client for administering the members of an organization.
Fields
api_configurations: Arc<ApiConfigurations>Implementations
impl OrganizationUsersManagementClient
impl OrganizationUsersManagementClient
pub async fn send_staged_invites(
&self,
organization_id: OrganizationId,
organization_user_ids: Vec<OrganizationUserId>,
) -> Result<Vec<OrganizationUserBulkResponse>, OrganizationUsersManagementError>
pub async fn send_staged_invites( &self, organization_id: OrganizationId, organization_user_ids: Vec<OrganizationUserId>, ) -> Result<Vec<OrganizationUserBulkResponse>, OrganizationUsersManagementError>
Sends invites to the given staged members, promoting them to invited and consuming a seat.
Returns an Err if the entire request fails. Otherwise returns Ok containing success or
failure information for each member.
pub async fn bulk_reinvite(
&self,
organization_id: OrganizationId,
organization_user_ids: Vec<OrganizationUserId>,
) -> Result<Vec<OrganizationUserBulkResponse>, OrganizationUsersManagementError>
pub async fn bulk_reinvite( &self, organization_id: OrganizationId, organization_user_ids: Vec<OrganizationUserId>, ) -> Result<Vec<OrganizationUserBulkResponse>, OrganizationUsersManagementError>
Re-sends the invitation email to the given invited members.
Returns an Err if the entire request fails. Otherwise returns Ok containing success or
failure information for each member.
pub async fn reinvite(
&self,
organization_id: OrganizationId,
organization_user_id: OrganizationUserId,
) -> Result<(), OrganizationUsersManagementError>
pub async fn reinvite( &self, organization_id: OrganizationId, organization_user_id: OrganizationUserId, ) -> Result<(), OrganizationUsersManagementError>
Re-sends the invitation email to a single invited member.